@@ -3,12 +3,21 @@ import tkinter as tk
 from matplotlib.backends.backend_tkagg import FigureCanvasTkAgg
 from pandas import DataFrame
 import matplotlib.pyplot as plt
+import os
 
 from tkcalendar import Calendar
-import nlp
+# [1] https://towardsdatascience.com/synonyms-and-antonyms-in-python-a865a5e14ce8
+# [2] https://spacytextblob.netlify.app/docs/example
+import nltk
+import spacy
+from nltk.corpus import wordnet
+from spacytextblob.spacytextblob import SpacyTextBlob
+import en_core_web_sm
 
 
-def main(): 
+window = Tk()
+
+def main():
     main = MainView(window)
     main.pack(side="top", fill="both", expand=True)
     window.title("HackerTracker")
@@ -17,6 +26,54 @@ def main():
 
 
 
+def nlpFunc(text):
+
+    nlp = en_core_web_sm.load()
+    nlp.add_pipe("spacytextblob")
+   # [1]
+    synonyms = []
+    
+    # [2] NLP analysis of single-line text
+    doc = nlp(text)
+
+    # print(doc._.assessments)
+
+    if len(text) != 0:
+        
+        # list comphresion to get the emotional words
+        words = list(zip(*doc._.assessments))
+        
+        # for index in range(0, len(words)):
+        if(len(words) != 0):
+            word = list(zip(*words[0]))
+            print(word)
+            word3 = list(zip(*word))
+
+            for index in range(0, len(word3)):
+                # print(index, "-", *word3[index])
+
+                # Word Cloud
+                # [1] looks for synonym(s) of the emotional word(s)
+                for syn in wordnet.synsets(*word3[index]):
+                    # [1] returns the synonyms of the emotional word(s)
+                    for lm in syn.lemmas():
+                        # [1] adds the snonym(s) to the synonyms list
+                        synonyms.append(lm.name())
+                # [1] prints the synonym(s) of the emotional word(s)
+                print(set(synonyms))
+
+            # [2] Input multiple lines of text
+            docs = list(nlp.pipe([text]))
+        else:
+            synonyms = ["no synonyms found"]
+
+        # for doc in docs:
+            # print('Assessments:', doc._.assessments)
+    else:
+        synonyms = ["Please enter text"]
+        
+    return synonyms
+
 '''def homeScreen():
     window = Tk()
     window.title("HackerTracker")
@@ -385,7 +442,10 @@ class Page5(Page):
             self.inputs[8] = 5
 
      def savetoFile(self):
-         with open("saveData.txt", "a") as file:
+         path = r"saveData.txt"
+         assert os.path.isfile(path)
+         with open(path, "r") as file:
+             pass
              file.write(str(self.date))
              file.write(" ")
              for i in self.inputs:
@@ -444,7 +504,7 @@ class Page6(Page):
                 break
             else:
                 label.grid_forget()
-        self.nlpList = nlp.nlpFunc(word)
+        self.nlpList = nlpFunc(word)
         counter = 0
         for i in self.nlpList:
             graph_this = Label(self, text=self.nlpList[counter], justify='center', font=("Comic Sans MS", 20, 'bold'), bg="black", fg='SpringGreen2')
@@ -543,5 +603,4 @@ class MainView(tk.Frame):
 
 
 if __name__ == "__main__":
-    window = Tk()
     main()
\ No newline at end of file
